@@ -1,4 +1,12 @@
-# -*- coding: utf-8 -*-
+#!/usr/bin/env python3
+
+"""
+dycall.demangler
+~~~~~~~~~~~~~~~~
+
+Contains `DemanglerWindow`.
+"""
+
 import logging
 
 import ttkbootstrap as tk
@@ -6,22 +14,29 @@ from ttkbootstrap import ttk
 from ttkbootstrap.dialogs import Messagebox
 from ttkbootstrap.localization import MessageCatalog as MsgCat
 
-from dycall.util import CopyButton, DemangleError, demangle, set_app_icon
+from dycall.util import CopyButton, DemangleError, demangle
 
 log = logging.getLogger(__name__)
 
 
 class DemanglerWindow(tk.Toplevel):
-    def __init__(self, parent: tk.Window):
+    """A C++ symbol name demangler utility.
+
+    Found under **Tools** -> **Demangler** in the top menu.
+    Uses `dycall.util.demangle` to demangle the name.
+
+    TODO: Syntax highlighted demangled name using Pygments.
+    """
+
+    def __init__(self, _: tk.Window):
         log.debug("Initialising")
-        self.parent = parent
         self.mangled_name = mangled_name = tk.StringVar()
         self.demangled_name = demangled_name = tk.StringVar()
 
-        super().__init__(title="Demangler")
+        super().__init__(title="Demangler", toolwindow=True)
         self.withdraw()
-        set_app_icon(self)
         self.minsize(300, 100)
+        self.resizable(True, False)
         self.geometry("500x100")
 
         self.columnconfigure(0)
@@ -36,7 +51,9 @@ class DemanglerWindow(tk.Toplevel):
             self, text="Demangle", command=self.demangle, state="disabled"
         )
         self.dl = dl = ttk.Label(self, text="Demangled")
-        self.de = de = ttk.Entry(self, textvariable=demangled_name, state="readonly")
+        self.de = de = ttk.Entry(
+            self, textvariable=demangled_name, state="readonly", font="TkFixedFont"
+        )
         self.db = db = CopyButton(self, demangled_name, state="disabled")
 
         # https://www.tutorialspoint.com/how-do-i-get-an-event-callback-when-a-tkinter-entry-widget-is-modified
@@ -49,16 +66,20 @@ class DemanglerWindow(tk.Toplevel):
         de.grid(row=1, column=1, padx=5, pady=(0, 10), sticky="ew")
         db.grid(row=1, column=2, padx=5, pady=(0, 10), sticky="w")
 
+        self.place_window_center()
         self.deiconify()
+        self.focus_set()
         log.debug("Initialised")
 
     def set_state(self, *_):
+        """Toggles the state of the **Demangle** button based on **Name**."""
         if self.me.get():
             self.mb.configure(state="normal")
         else:
             self.mb.configure(state="disabled")
 
     def demangle(self):
+        """Tries to demangle **Name** and update the **Demangled** entry."""
         mangled = self.mangled_name.get()
         try:
             d = demangle(mangled)
