@@ -1,4 +1,7 @@
-# -*- coding: utf-8 -*-
+#!/usr/bin/env python3
+
+"""Pytest fixtures"""
+
 import appdirs
 import pytest
 
@@ -7,6 +10,8 @@ from dycall.app import App
 
 @pytest.fixture
 def create_app(monkeypatch, tmp_path):
+    """Instantiates DyCall with a monkeypatched config dir."""
+
     def mock_config_dir(*_):
         return tmp_path
 
